==> generator-efigence-0.0.2.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var generators = require('yeoman-generator');
var mkdirp = require('mkdirp');

var SimpleappGenerator = generators.Base.extend({
  init: function () {
    this.pkg = require('../package.json');

    this.on('end', function () {
    	console.log('end');
    	console.log(this.appName);
      // if (!this.options['skip-install']) {
      //   this.installDependencies();
      // }
    });
  },

  prompting: function () {
    var done = this.async();

    // have Yeoman greet the user
    //this.log(this.yeoman);
    // // replace it with a short and sweet description of your generator
    this.log('You\'re using the fantastic Simpleapp generator.');

    var prompts = [{
    	  type: "input",
      	name: 'appName',
      	message: "Nazwa aplikacji"
    }];



    this.prompt(prompts, function (props) {
      this.appName = props.appName;
      // this.config = {
      //   app: 'app',
      //   dist: 'dist',
      //   tmp:  '.tmp'
      // }

      done();
    }.bind(this));

  },

  app: function () {

  	//console.log('app');

    if( this.appName === null || this.appName === ""){
      return;
    }

    mkdirp(this.appName);

     var _package = [
       "gulp",
       "gulp-util",
    //   // "gulp-clean",
    //   // "gulp-concat",
        "gulp-connect",
    //   // "gulp-csscomb",
    //   // "gulp-load-plugins",
    //   // "gulp-minify-css",
         "gulp-plumber",
    //   // "gulp-prettify",
    //   // "gulp-purifycss",
          "gulp-sass",
    //   // "gulp-sourcemaps",
    //   // "gulp-uglify",
        "gulp-watch"
    //   //"node-normalize-scs"
       ];

    for( var i = 0; i < _package.length; i++){
      console.log(_package[i]);
       this.npmInstall([_package[i]], { 
        'saveDev' : true,
        'prefix' : this.appName
      });
    }

    //basic project structure

    var _appStructure = [
     "/src",
     "/src/fonts",
     "/src/js",
     "/src/styles",
     "/src/img",
     "/public"
    ];

    for( var i = 0; i < _appStructure.length; i++){
      mkdirp(this.appName + _appStructure[i]);  
    }


    this.fs.copyTpl(
      this.templatePath('src/index.html'),
      this.destinationPath(this.appName + '/src/index.html'),
      { title: this.appName }
    );
    this.fs.copyTpl(
      this.templatePath('src/gulpfile.js'),
      this.destinationPath(this.appName + '/gulpfile.js')
    );

    // this.write('app/javascripts/application.coffee', '# Main CoffeeScript File');
    // this.write('app/stylesheets/application.sass', '// Use @import to link all components');

    // this.template('Gruntfile.coffee', 'Gruntfile.coffee');
    // this.directory('grunt', 'grunt', true);
    // this.template('index.html', 'app/index.html');

    // this.template('_package.json', 'package.json');
    // this.template('_bower.json', 'bower.json');
  }

  // runtime: function () {
  //   // this.copy('bowerrc', '.bowerrc');
  //   // this.copy('gitignore', '.gitignore');
  // },

  // projectfiles: function () {
  //   // this.copy('editorconfig', '.editorconfig');
  //   // this.copy('jshintrc', '.jshintrc');
  // }
});

module.exports = SimpleappGenerator;

==> generator-efigence-0.0.3.tgz: package/app/index.js <==
'use strict';
var util = require('util');
var path = require('path');
var generators = require('yeoman-generator');
var mkdirp = require('mkdirp');

var EfigenceGenerator = generators.Base.extend({

  init: function () {

    this.pkg = require('../package.json');

    this.on('end', function () {

    	console.log('end');
      // if (!this.options['skip-install']) {
      //   this.installDependencies();
      // }
    });
  },

  prompting: function () {

    var done = this.async();
  
    this.log('███████╗███████╗██╗ ██████╗ ███████╗███╗   ██╗ ██████╗███████╗');
    this.log('██╔════╝██╔════╝██║██╔════╝ ██╔════╝████╗  ██║██╔════╝██╔════╝');
    this.log('█████╗  █████╗  ██║██║  ███╗█████╗  ██╔██╗ ██║██║     █████╗  ');
    this.log('██╔══╝  ██╔══╝  ██║██║   ██║██╔══╝  ██║╚██╗██║██║     ██╔══╝  ');
    this.log('███████╗██║     ██║╚██████╔╝███████╗██║ ╚████║╚██████╗███████╗');
    this.log('╚══════╝╚═╝     ╚═╝ ╚═════╝ ╚══════╝╚═╝  ╚═══╝ ╚═════╝╚══════╝');
    this.log('This is Efigence Simple app generator. Enjoy! ( ͡° ͜ʖ ͡°)');                                                           

    var prompts = [{
    	  type: "input",
      	name: 'appName',
      	message: "Nazwa aplikacji"
    }];

    this.prompt(prompts, function (props) {
      this.appName = props.appName;
      // this.config = {
      //   app: 'app',
      //   dist: 'dist',
      //   tmp:  '.tmp'
      // }

      done();
    }.bind(this));

  },

  app: function () {

  	//console.log('app');

    if( this.appName === null || this.appName === ""){
      return;
    }

    mkdirp(this.appName);

    var _package = [
      "gulp",
      "gulp-util",
      "gulp-concat",
      "gulp-connect",
      // "gulp-load-plugins",
      "cssnano",
      "gulp-plumber",
      // "gulp-prettify",
      // "gulp-purifycss",
      "gulp-sass",
      "gulp-sourcemaps",
      // "gulp-uglify",
      "gulp-watch",
      "foundation",
      "jquery"
      //"node-normalize-scs"
    ];

    for( var i = 0; i < _package.length; i++){
      
       this.npmInstall([_package[i]], { 
        'saveDev' : true,
        'prefix' : this.appName
      });
    }

    //basic project structure

    var _appStructure = [
     "/src",
     "/src/fonts",
     "/src/js",
     "/src/styles",
     "/src/img",
     "/public"
    ];

    for( var i = 0; i < _appStructure.length; i++){
      mkdirp(this.appName + _appStructure[i]);  
    }

    this.fs.copyTpl(
      this.templatePath('src/index.html'),
      this.destinationPath(this.appName + '/src/index.html'),
      { title: this.appName }
    );

     this.fs.copyTpl(
      this.templatePath('src/js/app.js'),
      this.destinationPath(this.appName + '/src/js/app.js')
    );

    this.fs.copyTpl(
      this.templatePath('src/styles/app.scss'),
      this.destinationPath(this.appName + '/src//styles/app.scss')
    );

    this.fs.copyTpl(
      this.templatePath('src/gulpfile.js'),
      this.destinationPath(this.appName + '/gulpfile.js')
    );

    // this.write('app/javascripts/application.coffee', '# Main CoffeeScript File');
    // this.write('app/stylesheets/application.sass', '// Use @import to link all components');

    // this.template('Gruntfile.coffee', 'Gruntfile.coffee');
    // this.directory('grunt', 'grunt', true);
    // this.template('index.html', 'app/index.html');

    // this.template('_package.json', 'package.json');
    // this.template('_bower.json', 'bower.json');
  }

  // runtime: function () {
  //   // this.copy('bowerrc', '.bowerrc');
  //   // this.copy('gitignore', '.gitignore');
  // },

  // projectfiles: function () {
  //   // this.copy('editorconfig', '.editorconfig');
  //   // this.copy('jshintrc', '.jshintrc');
  // }
});

module.exports = EfigenceGenerator;
